@@ -117,6 +117,7 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
 #  fcount <- fscore;
   
   totFeatures <- length(varincluded);
+  largeSet <- (totFeatures > 1000) || ((nrow(refdata) > 1000) && (totFeatures > 100))
   
 
   
@@ -124,6 +125,7 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
   
   if (useFastCor)
   {
+#    cormat <- abs(Rfast::cora(as.matrix(refdata[,varincluded]),large=largeSet))
     cormat <- abs(Rfast::cora(as.matrix(refdata[,varincluded])))
   }else
   {
@@ -132,13 +134,35 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
   diag(cormat) <- 0;
   maxcor <- apply(cormat,2,max)
   totcorr <- sum(cormat >= 0.5); ## For False Discovery estimation
-  varincluded <- names(maxcor)[maxcor >= 0.35*thr];
+  totAtcorr <- sum(cormat >= thr); ## 
   DeCorrmatrix <- NULL;
   lastintopfeat <- character();
   lastdecorrelated <- character();
   totused <- character();
   totalpha <- character();
   outcomefeatures <- drivingFeatures;
+  bfeat <- NULL
+#  print(totFeatures)
+  adjunipvalue <- min(c(unipvalue,unipvalue*(sqrt(1.0 + totcorr))/totFeatures)); ## Adjusting for false association
+  
+  ## Min Correlation based on the pearson distribution
+  ndf <- nrow(data)-2
+#  print(c(ndf,adjunipvalue))
+  tvalue <- qt(1.0 - adjunipvalue,ndf)
+#  print(tvalue)
+  rcrit <- tvalue/sqrt(ndf + tvalue^2)
+  if (thr < rcrit) thr <- rcrit
+  
+  ################################# end #######################
+  althr <- 0.25;
+  cortoInclude <- max(c(althr*thr,rcrit))
+  
+  varincluded <- names(maxcor)[maxcor >= cortoInclude];
+  if (length(varincluded) > 2000) althr <- 0.5;
+  cortoInclude <- max(c(althr*thr,rcrit))  
+  varincluded <- names(maxcor)[maxcor >= cortoInclude];
+  allFeatAdded <- character()
+ 
   if (length(varincluded) > 1)
   {
       if (!is.null(Outcome))
@@ -147,11 +171,11 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
           {
             if (inherits(data[,Outcome],"factor") | (length(unique(data[,Outcome])) == 2))
             {
-              outcomep <- univariate_correlation(data,Outcome,limit=0,pvalue=unipvalue,thr = sqrt(thr)) # the top associated features to the outcome
+              outcomep <- univariate_correlation(data,Outcome,limit=0,pvalue= 0.1*unipvalue,thr = 0.95*thr) # the top associated features to the outcome
             }
             else
             {
-              outcomep <- univariate_correlation(data,Outcome,method=method,limit=0,pvalue=unipvalue,thr = sqrt(thr)) # the top associated features to the outcome
+              outcomep <- univariate_correlation(data,Outcome,method=method,limit=0,pvalue= 0.1*unipvalue,thr = 0.95*thr) # the top associated features to the outcome
             }
             outcomefeatures <- attr(outcomep,"Unadjusted");
             outcomefeatures <- names(outcomefeatures[outcomefeatures < unipvalue])
@@ -160,18 +184,23 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
           }
       }
       cormat <- cormat[varincluded,varincluded];
-      cormat[cormat < thr] <- 0;
+      ordcor <- apply(cormat,2,mean)
+
       maxcor <- apply(cormat,2,max)
       AdrivingFeatures <- varincluded;
       names(AdrivingFeatures) <- AdrivingFeatures;
+      AdrivingFeatures <- AdrivingFeatures[order(-ordcor[AdrivingFeatures])];
+      ordcor <- apply(1*(cormat>=thr),2,mean)
+      AdrivingFeatures <- AdrivingFeatures[order(-ordcor[AdrivingFeatures])];
       ordcor <- maxcor;
       if (corRank)
       {       
         ordcor <- apply(cormat^2,2,sum);
       }
       AdrivingFeatures <- AdrivingFeatures[order(-ordcor[AdrivingFeatures])];
+#      print(AdrivingFeatures)
       AdrivingFeatures <- as.character(correlated_Remove(cormat,AdrivingFeatures,thr = 0.95*thr,isDataCorMatrix=TRUE))
-      adjunipvalue <- min(unipvalue,unipvalue*sqrt(totcorr)/totFeatures); ## Adjusting for false association
+      
       DeCorrmatrix <- diag(length(varincluded));
       colnames(DeCorrmatrix) <- varincluded;
       rownames(DeCorrmatrix) <- varincluded;
@@ -191,14 +220,13 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
           AdrivingFeatures <- AdrivingFeatures[AdrivingFeatures %in% bfeat];
         }
       }
-      
+
       if (verbose) cat ("\n Included:",length(varincluded),", Uni p:",adjunipvalue,", Uncorrelated Base:",length(AdrivingFeatures),", Outcome-Driven Size:",length(drivingFeatures),", Base Size:",length(bfeat),"\n")
 
       relaxalpha <- 0.80;
       relaxbeta <- 0.20;
       thr2 <- thr
       thr <- thr2*1.001;
-#      wthr <- relaxalpha - relaxalpha*(!relaxed);
       thrvalues <- c(0.95,0.90,0.80,0.70,0.50,0.25,0.10);
       nextthr <- 1 + (!relaxed)*length(thrvalues);
       nextthra <- 0;
@@ -207,23 +235,19 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
         lp = lp + 1;
 
         addedlist <- 0;
-
         
-        cormat[cormat < thr2] <- 0;
         maxcor <- apply(cormat,2,max)
         mxScor <- max(maxcor);
 
 
         if ((mxScor >= thr2) && (nextthr <= length(thrvalues)))
         {
-#          thr <- max(c(thr2,thr2 + wthr*(max(maxcor) - thr2)));
            thr <- max(c(thr2,0.5*thrvalues[nextthr] + 0.5*mxScor));
         }
         else
         {
           thr <- thr2;
         }
-#        if (verbose)  cat("\n\r",lp,sprintf("<R=%5.3f,w=%5.3f,thr=%5.3f>",max(maxcor),wthr,thr))
 
         topfeat <- varincluded;
         names(topfeat) <- topfeat;
@@ -241,11 +265,16 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
           betamatrix <- diag(length(varincluded));
           colnames(betamatrix) <- varincluded;
           rownames(betamatrix) <- varincluded;
+          ordcor <- apply(cormat,2,mean)
+          topfeat <- topfeat[order(-ordcor[topfeat])];
+          ordcor <- apply(1*(cormat >= thr2),2,mean)
+          topfeat <- topfeat[order(-ordcor[topfeat])];
           ordcor <- maxcor;
           if (corRank)
           {
-            ordcor <- apply(cormat^2,2,sum);
+            ordcor <- apply(cormat^2,2,mean);
           }
+          ordcor <- ordcor + 1.0*(names(ordcor) %in% allFeatAdded)
           topfeat <- topfeat[order(-ordcor[topfeat])];
           atopbase <- bfeat[bfeat %in% topfeat];
           topfeat <- unique(c(atopbase,topfeat));
@@ -382,10 +411,6 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
                     }
                     fscore[feat] <- fscore[feat] + length(varlist);
                     fscore[varlist] <- fscore[varlist] - 1;
-#                    fscore[feat] <- fscore[feat] + sum(1.0-cormat[varlist,feat]^2)
-#                    fscore[varlist] <- fscore[varlist] - cormat[varlist,feat]^2
-#                    fcount[feat] <- fcount[feat] + length(varlist);
-#                    fcount[varlist] <- fcount[varlist] + 1;
                     cormat[ovarlist,feat] <- 0;
 
                   }
@@ -394,6 +419,7 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
                       featMarked <- unique(c(featMarked,feat));
                   }
               }
+              allFeatAdded <- unique(c(allFeatAdded,featAdded))
               if (!testedMedian)
               {
                 featAdded <- character();
@@ -407,7 +433,7 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
             }
           }
           addedlist <- length(decorrelatedFetureList);
-          if (verbose) cat("[",lpct,":",length(featMarked),":",sprintf("%5.3f",themaxthr),"](",length(intopfeat),",",addedlist,",",length(totalpha),"),<")
+          if (verbose) cat("[",lpct,":",length(featMarked),"Fa=",length(allFeatAdded),":",sprintf("%5.3f",themaxthr),"](",length(intopfeat),",",addedlist,",",length(totalpha),"),<")
           if (addedlist > 0)
           {
              mbetas <- c(intopfeat,decorrelatedFetureList);
@@ -435,7 +461,6 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
                 {
                    mtx1 <- t(as.matrix(DeCorrmatrix[totalphaused,allused]))
                    mtx2 <- as.matrix(betamatrix[allused,colused])
-#                   cat("..no Fast..[",ncol(mtx1),"][",nrow(mtx2),"]")
                    DeCorrmatrix[totalphaused,colused] <- mtx1 %*% mtx2;
                 }
               }
@@ -457,7 +482,6 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
                   {
                      mtx1 <- as.matrix(refdata[,alphaused])
                      mtx2 <- t(as.matrix(betamatrix[alphaused,colused]))
-#                     cat("..no Fast..[",ncol(mtx1),"][",nrow(mtx2),"]")
                      refdata[,colused] <- refdata[,colused] + mtx1 %*% mtx2;
                   }
                 }
@@ -476,7 +500,7 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
           topFeatures <- unique(c(topFeatures,intopfeat));
           if (useFastCor)
           {
-            cormat <- abs(Rfast::cora(as.matrix(refdata[,varincluded])))
+             cormat <- abs(Rfast::cora(as.matrix(refdata[,varincluded])))
           }
           else
           {
@@ -491,7 +515,6 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
           {
             if ((sum(intopfeat %in% lastintopfeat) == length(intopfeat)) && (sum(decorrelatedFetureList %in% lastdecorrelated) == length(decorrelatedFetureList)))
             {
-#              if (verbose) cat (decorrelatedFetureList);
               addedlist <- 0;
             }
           }          
@@ -501,11 +524,6 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
 
         if ((nextthr <= length(thrvalues)) && ((addedlist <= max(c(2.0,0.1*orglentopfeat))) || (length(intopfeat) <= 1)))
         {
-#          wthr <- wthr - relaxbeta;
-#          if (verbose) 
-#          {
-#            cat ("orglentopfeat:",orglentopfeat,", addedlist:",addedlist,", intopfeat:",length(intopfeat));
-#          }
           nextthr <- nextthr + 1; 
         }
       }
@@ -519,7 +537,6 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
       {
         DeCorrmatrix <- DeCorrmatrix[varincluded,varincluded]
         abfeat <- varincluded[apply(DeCorrmatrix!=0,2,sum)==1]
-#        if (verbose) cat("-{",abfeat[!(abfeat %in% bfeat)],"}-")
         bfeat <- unique(c(bfeat,abfeat));
         dataTransformed <- data
         if (length(varincluded) > 1)
@@ -563,26 +580,17 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
               diag(cormat) <- 0;
               cat ("\n\r [",lp,"],",max(cormat),"Decor Dimension:",length(varincluded),". Cor to Base:",length(correlatedToBase),", ABase:",length(AdrivingFeatures),", Outcome Base:",length(drivingFeatures),"\n\r")
           }
-#          banames <- colnames(DeCorrmatrix)[apply(DeCorrmatrix!=0,2,sum)==1]
           changed <- (apply(DeCorrmatrix!=0,2,sum) > 1);
           lavariables <- colnames(DeCorrmatrix)[changed]
           newnames <- colnames(dataTransformed)
-#          newnames[newnames %in% bfeat] <- paste("Ba_",newnames[newnames %in% bfeat],sep="") 
-#          newnames[newnames %in% varincluded] <- paste("La_",newnames[newnames %in% varincluded],sep="")
           newnames[newnames %in% lavariables] <- paste("La_",newnames[newnames %in% lavariables],sep="")
           colnames(dataTransformed) <- newnames
           newnames <- colnames(DeCorrmatrix)
-#          newnames[newnames %in% bfeat] <- paste("Ba_",newnames[newnames %in% bfeat],sep="") 
-#          newnames[newnames %in% varincluded] <- paste("La_",newnames[newnames %in% varincluded],sep="")
           newnames[newnames %in% lavariables] <- paste("La_",newnames[newnames %in% lavariables],sep="")
           colnames(DeCorrmatrix) <- newnames
           fscore <- fscore[varincluded];
-#          fcount <- fcount[varincluded];
-#          fscore <- fscore/fcount;
 
           newnames <- names(fscore)
-#          newnames[newnames %in% bfeat] <- paste("Ba_",newnames[newnames %in% bfeat],sep="") 
-#          newnames[newnames %in% varincluded] <- paste("La_",newnames[newnames %in% varincluded],sep="")
           newnames[newnames %in% lavariables] <- paste("La_",newnames[newnames %in% lavariables],sep="")
           names(fscore) <- newnames
         }
@@ -602,6 +610,8 @@ getAllBetaCoefficients <- function(feat,varlist=NULL)
   attr(dataTransformed,"LatentVariables") <- lavariables;
   attr(dataTransformed,"useDeCorr") <- useDeCorr;
   attr(dataTransformed,"unipvalue") <- adjunipvalue
+  attr(dataTransformed,"totCorrelated") <- totAtcorr
+  attr(dataTransformed,"R.critical") <- rcrit
   return(dataTransformed)
 }
 
